//verificação se o ambiente é de homologação ou produção
if (process.env.NODE_ENV !== 'development') {
    require('dotenv').config()
}

import axios from 'axios';
import fs from 'fs';
import path from 'path';
import https from 'https';
import { createTRPCRouter, publicProcedure } from "~/server/api/trpc";
import { supabase } from "../supabase";


//leitura do certificado
const cert = fs.readFileSync(
    path.resolve(__dirname, `${process.env.EFI_CERT}`)
);

//requisições https a partir do certificado
const agent = new https.Agent({
    pfx: cert,
    passphrase: ''
})

//leitura das credenciais
const credentials = Buffer.from(
    `${process.env.EFI_CLIENT_ID}:${process.env.EFI_CLIENT_SECRET}`
).toString('base64')

export const createChargeRouter = createTRPCRouter({
    createCharge: publicProcedure
        .mutation(async () => {
            const authResponse = await axios({
                method: 'POST',
                url: `${process.env.EFI_ENDPOINT}/oauth/token`,
                headers: {
                    Authorization: `Basic ${credentials}`,
                    'Content-Type': 'application/json',
                },
                httpsAgent: agent,
                data: {
                    grant_type: 'client_credentials'
                }
            });


            const accessToken = await authResponse.data?.access_token;

            const reqEfi =  await axios.create({
                baseURL: process.env.EFI_ENDPOINT,
                httpsAgent: agent,
                headers: {
                    Authorization: `Bearer ${accessToken}`,
                    'Content-Type': 'application/json',
                timeout: 3600
                }
            })

            //dados da cobrança
            const dataCob = {
                calendario: {
                    expiracao: 3600
                },
                valor: {
                    original: '0.01'
                },
                chave: 'retirei a chave por segurança',
                solicitacaoPagador: 'Cobrança dos serviços prestados.',
            };

            const cobResponse = await reqEfi.post('v2/cob', dataCob);

            const qrcodeResponse = await reqEfi.get(`/v2/loc/${cobResponse.data.loc.id}/qrcode`);
            console.log(qrcodeResponse.data);

            return { qrcodeImage: qrcodeResponse.data.imagemQrcode }
        })
})
